from machine import Pin, SPI, ADC
import struct
from time import sleep_ms

from nrf24l01 import NRF24L01

led = Pin(25, Pin.OUT)                # LED
btn = Pin(23, Pin.IN, Pin.PULL_DOWN)  # button press
csn = Pin(5, mode=Pin.OUT, value=1)  # chip select not
ce  = Pin(9, mode=Pin.OUT, value=0)  # chip enable

data_type = "I"
# Addresses are in little-endian format. They correspond to big-endian
# 0xf0f0f0f0e1, 0xf0f0f0f0d2 - swap these on the other Pico!
pipes = (b"\xe1\xf0\xf0\xf0\xf0", b"\xd2\xf0\xf0\xf0\xf0")

def setup():
    nrf = NRF24L01(SPI(0, miso = Pin(4),mosi = Pin(7), sck= Pin(6)), csn, ce, payload_size=8)
    
    nrf.open_tx_pipe(pipes[0])
    nrf.open_rx_pipe(1, pipes[1])
    nrf.start_listening()

    led.value(0)
    return nrf

def auto_ack(nrf):
    nrf.reg_write(0x01, 0b11111000)  # enable auto-ack on all pipes

def recv_data(nrf,dtype):
    buf = nrf.recv()
    got = struct.unpack(dtype, buf)[0]
    x_axis = got & 0xFFFF
    y_axis = got >> 16
    return (x_axis,y_axis)

nrf = setup()
auto_ack(nrf)

while True:
    if nrf.any():
        x_data, y_data = recv_data(nrf,data_type)
        print(x_data,y_data)